@@ -1,40 +1,54 @@
 # ABSTRACT: Wunderlist.com API Client
 package API::Wunderlist;
 
-use namespace::autoclean -except => 'has';
-
 use Data::Object::Class;
-use Data::Object::Class::Syntax;
 use Data::Object::Signatures;
 
-use Data::Object qw(load);
-use Data::Object::Library qw(Str);
+use Data::Object::Library qw(
+    Str
+);
 
 extends 'API::Client';
 
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 our $DEFAULT_URL = "https://a.wunderlist.com";
 
 # ATTRIBUTES
 
-has client_id    => rw;
-has access_token => rw;
+has client_id => (
+    is       => 'rw',
+    isa      => Str,
+    required => 1,
+);
 
-# CONSTRAINTS
-
-req client_id    => Str;
-req access_token => Str;
+has access_token => (
+    is       => 'rw',
+    isa      => Str,
+    required => 1,
+);
 
 # DEFAULTS
 
-def identifier => 'API::Wunderlist (Perl)';
-def url        => method { load('Mojo::URL')->new($DEFAULT_URL) };
-def version    => 1;
+has '+identifier' => (
+    default  => 'API::Wunderlist (Perl)',
+    required => 0,
+);
+
+has '+url' => (
+    default  => $DEFAULT_URL,
+    required => 0,
+);
+
+has '+version' => (
+    default  => 1,
+    required => 0,
+);
 
 # CONSTRUCTION
 
 after BUILD => method {
+
     my $identifier   = $self->identifier;
     my $client_id    = $self->client_id;
     my $access_token = $self->access_token;
@@ -47,11 +61,13 @@ after BUILD => method {
     $url->path("/api/v$version");
 
     return $self;
+
 };
 
 # METHODS
 
 method PREPARE ($ua, $tx, %args) {
+
     my $headers = $tx->req->headers;
     my $url     = $tx->req->url;
 
@@ -59,9 +75,11 @@ method PREPARE ($ua, $tx, %args) {
     $headers->header('X-Client-ID' => $self->client_id);
     $headers->header('X-Access-Token' => $self->access_token);
     $headers->header('Content-Type' => 'application/json');
+
 }
 
 method resource (@segments) {
+
     # build new resource instance
     my $instance = __PACKAGE__->new(
         debug        => $self->debug,
@@ -83,6 +101,7 @@ method resource (@segments) {
 
     # return resource instance
     return $instance;
+
 }
 
 1;
@@ -99,7 +118,7 @@ API::Wunderlist - Wunderlist.com API Client
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
